# -*- coding: utf-8 -*-
# Copyright (C) 2011 Romain Gauthier <romain.gauthier@masteri2l.org>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# The following class is part of the web.py project. So it is in the Public
# Domain. For more informations, please see the following URLs :
#
#   https://github.com/webpy/webpy/blob/master/LICENSE.txt
#   https://github.com/webpy/webpy/blob/master/web/utils.py
#
class Storage(dict):
    """
    A Storage object is like a dictionary except `obj.foo` can be used
    in addition to `obj['foo']`.

        >>> o = storage(a=1)
        >>> o.a
        1
        >>> o['a']
        1
        >>> o.a = 2
        >>> o['a']
        2
        >>> del o.a
        >>> o.a
        Traceback (most recent call last):
        ...
        AttributeError: 'a'

    """

    def __getattr__(self, key):
        try:
            return self[key]
        except KeyError, k:
            raise AttributeError, k


    def __setattr__(self, key, value):
        self[key] = value

    def __delattr__(self, key):
        try:
            del self[key]
        except KeyError, k:
            raise AttributeError, k

    def __repr__(self):
        return '<Storage ' + dict.__repr__(self) + '>'




# -*- coding: utf-8 -*-
# Copyright (C) 2011 Romain Gauthier <romain.gauthier@masteri2l.org>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Import from the standard library
import sys

from time import sleep

# Import from FeedParser
from config import config
from feedparser import parse

tail = []

def isnew(entry):
    for item in tail:
        if entry[config.key] == item[config.key]:
            return False
    return True


def show(entry):
    sys.stdout.write(config.format.format(**entry))
    sys.stdout.write("\n")
    sys.stdout.flush()


def loop():
    def cycle():
        global tail
        entries = parse(config.url).entries
        if config.reverse:
            entries.reverse()
        for entry in entries:
            if isnew(entry):
                tail = [entry] + tail[:100]
                show(entry)

    cycle()
    while not config.oneshot:
        sleep(config.interval)
        cycle()




# Setup file for feedstail
from setuptools import setup

# Import from feedstail
from feedstail import __version__


with open('README.rst') as readme:
    long_description = readme.read()

setup( name             = "feedstail"
     , description      = "A tail-f-like utility for feeds"
     , long_description = long_description
     , license          = "GNU General Public License v3"
     , url              = "https://gitorious.org/feedstail/feedstail"

     , author           = "Romain Gauthier"
     , author_email     = "romain.gauthier@masteri2l.org"

     , version          = __version__
     , scripts          = ['bin/feedstail']
     , packages         = ['feedstail']
     , data_files       = [('', ['README.rst', 'LICENSE.txt'])]
     , install_requires = ['argparse', 'FeedParser']

     , classifiers      =
         [ "Development Status :: 3 - Alpha"
         , "License :: OSI Approved :: GNU General Public License (GPL)"
         , "Operating System :: OS Independent"
         , "Programming Language :: Python :: 2.6"
         , "Topic :: Utilities"
         ]
      )

